{% load umap_tags %}
<div id="map"></div>
<!-- djlint:off -->
<script defer type="text/javascript">
  let MAP
  window.addEventListener('DOMContentLoaded', (event) => {
    MAP = new U.Map("map", {{ map_settings|notag|safe }});
  });
</script>
<!-- djlint:on -->
