<script type="text/javascript">
  window.addEventListener('DOMContentLoaded', (event) => {
    {% for m in messages %}
    {# We have just one, but we need to loop, as for messages API #}
    MAP.ui.alert({
      content: "{{ m }}",
      level: "{{ m.tags }}",
      duration: 100000
    })
  {% endfor %}
})
</script>
